@@ -4,7 +4,7 @@ use Moose;
 use Scalar::Util 'blessed';
 with 'Dist::Zilla::Role::PluginBundle::Easy', 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 sub configure {
 	my $self = shift;
@@ -55,6 +55,7 @@ sub configure {
 	# @Basic, with some modifications
 	$self->add_plugins(qw/PruneCruft ManifestSkip MetaYAML MetaJSON
 		License ReadmeAnyFromPod ExtraTests ExecDir ShareDir/);
+	$self->add_plugins([ExecDir => 'ScriptDir' => { dir => 'script' }]);
 	$self->add_plugins($installer);
 	$self->add_plugins(qw/Manifest TestRelease ConfirmRelease/);
 	$self->add_plugins($ENV{FAKE_RELEASE} ? 'FakeRelease' : 'UploadToCPAN');
@@ -70,6 +71,7 @@ built by DBOOK
 =head1 SYNOPSIS
 
  [@Author::DBOOK]
+ pod_tests = 1
  installer = MakeMaker::Awesome
  MakeMaker::Awesome.test_file[] = t/*.t
  Git::GatherDir.exclude_filename[0] = bad_file
@@ -144,6 +146,8 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
  [ReadmeAnyFromPod]
  [ExtraTests]
  [ExecDir]
+ [ExecDir / ScriptDir]
+ dir = script
  [ShareDir]
  [MakeMaker]
  [Manifest]
@@ -189,8 +193,9 @@ C<Grinnz>, change this when the main repository is elsewhere.
 Set the installer plugin to use. Allowed installers are
 L<MakeMaker|Dist::Zilla::Plugin::MakeMaker>,
 L<MakeMaker::Awesome|Dist::Zilla::Plugin::MakeMaker::Awesome>, and
-L<ModuleBuildTiny|Dist::Zilla::Plugin::ModuleBuildTiny>. Options for the
-selected installer can be specified using config slicing.
+L<ModuleBuildTiny|Dist::Zilla::Plugin::ModuleBuildTiny>. The default is
+C<MakeMaker>. Options for the selected installer can be specified using config
+slicing.
 
 =head2 pod_tests
 
